@@ -29,13 +29,25 @@
 #include <egg-screen-help.h>
 #include "geyes.h"
 
-gchar *theme_directories[] = {
-        GEYES_THEMES_DIR,
-        "~/.gnome/geyes-themes/"
-};
 #define NUM_THEME_DIRECTORIES 2
 #define HIG_IDENTATION  "    "
 
+gchar *theme_directories[NUM_THEME_DIRECTORIES];
+
+void
+theme_dirs_create ()
+{
+	static themes_created = FALSE;
+	
+	if (themes_created == TRUE)
+		return;
+
+	theme_directories[0] = g_strdup (GEYES_THEMES_DIR);
+	theme_directories[1] = g_strdup_printf ("%s/.gnome2/geyes-themes/", g_get_home_dir());
+
+	themes_created = TRUE;
+}
+
 static void
 parse_theme_file (EyesApplet *eyes_applet, FILE *theme_file)
 {
@@ -194,7 +206,7 @@ theme_selected_cb (GtkTreeSelection *selection, gpointer data)
 	g_return_if_fail (theme);
 	
 	theme_dir = g_strdup_printf ("%s/", theme);
-	if (!g_strcasecmp (theme_dir, eyes_applet->theme_dir)) {
+	if (!g_ascii_strncasecmp (theme_dir, eyes_applet->theme_dir, strlen (theme_dir))) {
 		g_free (theme_dir);
 		return;
 	}
@@ -372,7 +384,8 @@ properties_cb (BonoboUIComponent *uic,
                                         gtk_list_store_insert (model, &iter, 0);
                                         gtk_list_store_set (model, &iter, 0, &filename, -1);
                                         theme_dir = g_strdup_printf ("%s/", filename);
-                                        if (!g_strcasecmp (eyes_applet->theme_dir, theme_dir)) {
+                                        
+					if (!g_ascii_strncasecmp (eyes_applet->theme_dir, theme_dir, strlen (theme_dir))) {
                                         	GtkTreePath *path;
                                         	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
                                                         			&iter);
