@@ -19,7 +19,7 @@
 
 #include "gtk/gtk.h"
 
-extern void GSwitchItHelp (GtkWindow * appWindow, const gchar * bookmark);
+extern void GSwitchItHelp (GtkWidget * appWidget, const gchar * bookmark);
 
 extern void GSwitchItInstallGlibLogAppender (void);
 
