@@ -29,6 +29,7 @@
 
 #include "popcheck.h"
 #include "remote-helper.h"
+#include "mailcheck.h"
 
 #include "egg-screen-help.h"
 #include "egg-screen-exec.h"
@@ -681,6 +682,14 @@ mailcheck_execute_shell (MailCheck  *mailcheck,
 	}
 }
 
+void
+command_execute_shell (gpointer data,
+                       const char *command)
+{
+        MailCheck *mc = (MailCheck *) data;
+        mailcheck_execute_shell (mc, command);
+}
+
 static G_CONST_RETURN char *
 mail_animation_filename (MailCheck *mc)
 {
@@ -1069,6 +1078,7 @@ after_mail_check (MailCheck *mc)
 {
 	static const char *supinfo[] = {"mailcheck", "new-mail", NULL};
 	char *text;
+	char *plural1, *plural2;
 
 	if (mc->anymail){
 		if(mc->mailbox_type == MAILBOX_LOCAL) {
@@ -1078,10 +1088,21 @@ after_mail_check (MailCheck *mc)
 				text = g_strdup(_("You have mail."));
 		}
 		else {
-			if(mc->unreadmail)
-				text = g_strdup_printf(_("%d unread/ %d messages"), mc->unreadmail, mc->totalmail);
+			if (mc->unreadmail) {
+				plural1 = g_strdup_printf(ngettext ("%d unread", "%d unread",  mc->unreadmail), mc->unreadmail);
+				plural2 = g_strdup_printf(ngettext ("%d message", "%d messages", mc->totalmail), mc->totalmail);
+
+				/* translators: this is of the form "%d unread/%d messages" */
+				text = g_strdup_printf(_("%s/%s"), plural1, plural2);
+
+				g_free (plural1);
+				g_free (plural2);
+			}
 			else
-				text = g_strdup_printf(_("%d messages"), mc->totalmail);
+				text = g_strdup_printf(ngettext ("%d message",
+								 "%d messages",
+								 mc->totalmail),
+						       mc->totalmail);
 		} 
 	}
 	else
@@ -1167,7 +1188,8 @@ mail_check_timeout (gpointer data)
 
 		mailcheck_execute_shell (mc, mc->pre_check_cmd);
 
-		mc->mail_timeout = gtk_timeout_add(mc->update_freq, mail_check_timeout, mc);
+		if(mc->auto_update)
+			mc->mail_timeout = gtk_timeout_add(mc->update_freq, mail_check_timeout, mc);
 	}
 
 	check_mail_file_status (mc);
@@ -2430,7 +2452,10 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 		NULL
 	};
 	const char *documenters [] = {
-	  NULL
+		"Eric Baudais <baudais@okstate.edu>",
+		"Telsa Gwynne <telsa@linuxchix.org>",
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
+	        NULL
 	};
 	const char *translator_credits = _("translator_credits");
 
