@@ -50,15 +50,15 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 {
 	if (!strcmp(iid, "OAFIID:GNOME_StickyNotesApplet")) {
 		if (!stickynotes)
-			stickynotes_applet_init();
+			stickynotes_applet_init (panel_applet);
 			
 		panel_applet_set_flags (panel_applet, PANEL_APPLET_EXPAND_MINOR);
 
 		/* Add applet to linked list of all applets */
-		stickynotes->applets = g_list_append(stickynotes->applets, stickynotes_applet_new(panel_applet));
+		stickynotes->applets = g_list_append (stickynotes->applets, stickynotes_applet_new(panel_applet));
 
-		stickynotes_applet_update_menus();
-		stickynotes_applet_update_tooltips();
+		stickynotes_applet_update_menus ();
+		stickynotes_applet_update_tooltips ();
 
 		return TRUE;
 	}
@@ -70,31 +70,87 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_StickyNotesApplet_Factory", PANEL_TYPE_APPLET, "stickynotes_applet", VERSION,
 			    stickynotes_applet_factory, NULL);
 
-/* Create and initalize global sticky notes instance */
-void stickynotes_applet_init()
+/* colorshift a pixbuf */
+static void
+stickynotes_make_prelight_icon (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 {
+	gint i, j;
+	gint width, height, has_alpha, srcrowstride, destrowstride;
+	guchar *target_pixels;
+	guchar *original_pixels;
+	guchar *pixsrc;
+	guchar *pixdest;
+	int val;
+	guchar r,g,b;
+
+	has_alpha = gdk_pixbuf_get_has_alpha (src);
+	width = gdk_pixbuf_get_width (src);
+	height = gdk_pixbuf_get_height (src);
+	srcrowstride = gdk_pixbuf_get_rowstride (src);
+	destrowstride = gdk_pixbuf_get_rowstride (dest);
+	target_pixels = gdk_pixbuf_get_pixels (dest);
+	original_pixels = gdk_pixbuf_get_pixels (src);
+
+	for (i = 0; i < height; i++) {
+		pixdest = target_pixels + i*destrowstride;
+		pixsrc = original_pixels + i*srcrowstride;
+		for (j = 0; j < width; j++) {
+			r = *(pixsrc++);
+			g = *(pixsrc++);
+			b = *(pixsrc++);
+			val = r + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			val = g + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			val = b + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			if (has_alpha)
+				*(pixdest++) = *(pixsrc++);
+		}
+	}
+}
+
+
+/* Create and initalize global sticky notes instance */
+void stickynotes_applet_init(PanelApplet *panel_applet)
+{	
+	GnomeIconTheme *icon_theme;
+	gchar *sticky_icon;
+
 	stickynotes = g_new(StickyNotes, 1);
 
 	stickynotes->notes = NULL;
 	stickynotes->applets = NULL;
-	stickynotes->icon_normal = gdk_pixbuf_new_from_file(STICKYNOTES_ICONDIR "/stickynotes.png", NULL);
-	stickynotes->icon_prelight = gdk_pixbuf_new_from_file(STICKYNOTES_ICONDIR "/stickynotes_prelight.png", NULL);
+
+	icon_theme = gnome_icon_theme_new ();
+	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme, "stock_notes", 48, NULL, NULL);
+
+	if (sticky_icon) {
+		gnome_window_icon_set_default_from_file(sticky_icon);
+		stickynotes->icon_normal = gdk_pixbuf_new_from_file(sticky_icon, NULL);
+	}
+	g_free (sticky_icon);
+	g_object_unref (icon_theme);
+
+	stickynotes->icon_prelight = gdk_pixbuf_new(gdk_pixbuf_get_colorspace (stickynotes->icon_normal),
+						    gdk_pixbuf_get_has_alpha (stickynotes->icon_normal),
+						    gdk_pixbuf_get_bits_per_sample (stickynotes->icon_normal),
+						    gdk_pixbuf_get_width (stickynotes->icon_normal),
+						    gdk_pixbuf_get_height (stickynotes->icon_normal));
+	stickynotes_make_prelight_icon (stickynotes->icon_prelight, stickynotes->icon_normal, 30);
 	stickynotes->gconf = gconf_client_get_default();
 	stickynotes->tooltips = gtk_tooltips_new();
 
 	stickynotes_applet_init_icons();
 	stickynotes_applet_init_prefs();
 
-	/* Set default icon for all sticky note windows */
-	gnome_window_icon_set_default_from_file(STICKYNOTES_ICONDIR "/stickynotes.png");
-
 	/* Watch GConf values */
 	gconf_client_add_dir(stickynotes->gconf, GCONF_PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/defaults", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/settings", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
 	
 	/* Load sticky notes */
-	stickynotes_load();
+	stickynotes_load(gtk_widget_get_screen(GTK_WIDGET(panel_applet)));
 	
 	/* Auto-save every so minutes (default 5) */
 	g_timeout_add(1000 * 60 * gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/autosave_time", NULL),
@@ -206,6 +262,7 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	/* Initialize Sticky Notes Applet */
 	applet->w_applet = GTK_WIDGET(panel_applet);
 	applet->w_image = gtk_image_new();
+	applet->about_dialog = NULL;
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
@@ -262,14 +319,14 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 
 	/* Choose appropriate icon and size it */
 	if (applet->prelighted)
-	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_prelight, size, size, GDK_INTERP_BILINEAR);
+	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_prelight, size - 3, size - 3, GDK_INTERP_BILINEAR);
 	else
-	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_normal, size, size, GDK_INTERP_BILINEAR);
+	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_normal, size - 3, size - 3, GDK_INTERP_BILINEAR);
 	
 	/* Shift the icon if pressed */
 	pixbuf2 = gdk_pixbuf_copy(pixbuf1);
 	if (applet->pressed)
-		gdk_pixbuf_scale(pixbuf1, pixbuf2, 0, 0, size, size, 1, 1, 1, 1, GDK_INTERP_BILINEAR);
+		gdk_pixbuf_scale(pixbuf1, pixbuf2, 0, 0, size - 3, size - 3, 1, 1, 1, 1, GDK_INTERP_BILINEAR);
 
 	/* Apply the finished pixbuf to the applet image */
 	gtk_image_set_from_pixbuf(GTK_IMAGE(applet->w_image), pixbuf2);
@@ -281,17 +338,23 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 void stickynotes_applet_update_prefs()
 {
 	gint width = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL);
+	width = MAX (width, 1);
 	gint height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
+	height = MAX (height, 1);
 	gboolean sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
 	gboolean sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
 	gint click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
 	gboolean sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
 	gboolean force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
 	gchar *font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
+	if (!font_str)
+		font_str = g_strdup ("Sans 10");
 	
 	GdkColor color;
 	{
 		gchar *color_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL);
+		if (!color_str)
+			color_str = g_strdup ("#FFFF00");
 		gdk_color_parse(color_str, &color);
 		g_free(color_str);
 	}
@@ -363,7 +426,7 @@ void stickynotes_applet_update_tooltips()
 	g_free(tooltip);
 }
 
-void stickynotes_applet_do_default_action()
+void stickynotes_applet_do_default_action(GdkScreen *screen)
 {
 	StickyNotesDefaultAction click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
 
@@ -372,7 +435,7 @@ void stickynotes_applet_do_default_action()
 
 	switch (click_behavior) {
 		case STICKYNOTES_NEW:
-			stickynotes_add();
+			stickynotes_add(screen);
 			break;
 
 		case STICKYNOTES_SET_VISIBLE:
